@@ -1383,7 +1383,7 @@ class CohortMetrics:
         interval_upper_bound = row.interval_upper_bound
 
         active_counts_at_intervals = row.filter(
-            regex=r"[0-9]", axis=0
+            regex=r"^\d+$", axis=0
         )  # select only the interval columns
         intervals = active_counts_at_intervals.index
         counts = active_counts_at_intervals.fillna(0).values
